pub struct StratificationLayer {
pub stratum: usize,
pub nodes: Vec<DepNode>,
pub has_negation: bool,
}Expand description
A set of nodes that can be evaluated at the same stratum.
Fields
stratum: usizeZero-based stratum index (lower = evaluated first).
nodes: Vec<DepNode>All nodes at this stratum (sorted for determinism).
has_negation: booltrue when at least one incoming edge to this stratum is Negative.