SchemaMigrationStep

Enum SchemaMigrationStep 

pub enum SchemaMigrationStep {
    AddPredicate {
        name: String,
        arity: usize,
    },
    RemovePredicate {
        name: String,
    },
    RenamePredicate {
        old_name: String,
        new_name: String,
    },
    AddArityColumn {
        predicate: String,
        position: usize,
        default_value: String,
    },
    RemoveArityColumn {
        predicate: String,
        position: usize,
    },
    AddDomain {
        name: String,
    },
    RemoveDomain {
        name: String,
    },
    AddRule {
        name: String,
    },
    RemoveRule {
        name: String,
    },
}
A concrete migration step to transform the old schema into the new schema.

Variants



AddPredicate

Create a new predicate slot.

Fields

name: String
arity: usize


RemovePredicate

Drop an existing predicate slot.

Fields

name: String


RenamePredicate

Rename a predicate (non-destructive when reverse is possible).

Fields

old_name: String
new_name: String


AddArityColumn

Extend a predicate by inserting a new positional argument.

Fields

predicate: String
position: usize
default_value: String


RemoveArityColumn

Shrink a predicate by removing a positional argument.

Fields

predicate: String
position: usize


AddDomain

Register a new domain.

Fields

name: String


RemoveDomain

Unregister an existing domain.

Fields

name: String


AddRule

Bind a new variable/rule entry.

Fields

name: String


RemoveRule

Remove an existing variable/rule entry.

Fields

name: String

Implementations

Source

impl SchemaMigrationStep

pub fn description(&self) -> String

Human-readable description of the step.

pub fn is_destructive(&self) -> bool

Returns true when this step is destructive (data may be lost).